#
# spec file for package vkquake
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2017 Luke Jones <luke.nukem.jones@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vkquake
Version:        1.20.3
Release:        bp156.2.12
Summary:        Quake 1 port using Vulkan instead of OpenGL for rendering
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            https://github.com/Novum/vkQuake
Source:         https://github.com/Novum/vkQuake/archive/refs/tags/%{version}.tar.gz#/vkQuake-%{version}.tar.gz
Source99:       %{name}.changes
Source100:      appdata.xml
Source101:      %{name}.desktop
BuildRequires:  pkgconfig
BuildRequires:  vulkan-devel
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(libmikmod)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vorbis)

%description
vkQuake is a Quake 1 port using Vulkan instead of OpenGL for rendering. It is based on the popular QuakeSpasm port and runs all mods compatible with it like Arcane Dimensions or In The Shadows.
Game data must be placed in ~/.vkquake/id1 .

%prep
%autosetup -p1 -n vkQuake-%{version}

%if 0%{?sle_version} < 150200
sed -i 's#vulkan_core.h#vulkan.h#' Quake/quakedef.h
%endif

# Drop pre-compiled Windows stuff
rm Windows -fr

# Fix usage of __DATE__ and __TIME__ macros to prevent build in excess
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE99}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g" Quake/host.c

%build
%make_build -C Quake \
    STRIP=": do not strip:" \
    DO_USERDIRS=1 \
    USE_SDL2=1 \
    USE_CODEC_FLAC=1 \
    USE_CODEC_OPUS=1 \
    USE_CODEC_MIKMOD=1 \
    USE_CODEC_UMX=1 \
    USE_CODEC_MP3=0
%make_build -C Misc/vq_pak
strip Quake/vkquake

%install
install -Dm755 Quake/vkquake %{buildroot}%{_bindir}/%{name}
install -Dm644 Misc/vq_pak/vkquake.pak %{buildroot}%{_datadir}/games/%{name}/%{name}.pak
install -D -p -m 644 Misc/vkQuake_512.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -D -p -m 644 %{SOURCE100} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml
install -D -p -m 644 %{SOURCE101} %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%license LICENSE.txt
%doc readme.md Misc/fitzquake080.txt Misc/fitzquake080sdl.txt Misc/fitzquake085.txt
%dir %{_datadir}/games/%{name}/
%{_bindir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/games/%{name}/%{name}.pak
%{_datadir}/pixmaps/%{name}.png

%changelog
* Sat Aug 13 2022 Michael Pujos <pujos.michael@gmail.com>
- Update to version 1.20.3
  * Fixed multiple parallelism bugs
  * 8-bit mode now has dithering
- Update to version 1.20.2
  * Fixed a crash on startup with re-release Quake data
  * Fixed crash with small stack sized on Unix (e.g. musl libc)
- Update to version 1.20.1
  * Fix a bug that could cause random lockups with 1.20.0
  * Fix screenshot crash
  * Fix corruption if new vkquake.pak is missing or old one is still in place
- Update to version 1.20.0
  * Parallelized renderer for significantly higher performance
  * Parallelized texture mip generation for faster load times
  * SIMD code optimizations
  * "8-bit" color mode emulation
  * Scaling is now less blurry
  * Mods menu
  * Completely replaced memory management (no more -heapsize)
* Mon May 16 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.13.1:
  * GUI scale is now relative to screen height (scr_relativescale 0
    to disable).
  * Crosshair is selectable from menu and added option for dot
    instead of cross.
  * Improved compatibility with latest Quake Steam re-release
    version.
  * Various smaller bug fixes
- Update to version 1.13.0:
  * GPU lightmap update and smooth dynamic light interpolation
  * Various bug fixes
  * Improved compatibility with 2021 Quake re-release
  Known issues:
  * Some entities don't animate smoothly with FTE protocol
    extensions. cl_nopext 1 is a workaround right now.
    Same bug exists in QSS.
* Fri Feb 18 2022 Matthias Mailänder <mailaender@opensuse.org>
- Fix screenshot URL
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to 1.12.2:
  * Improved compatibility with the 2021 Quake re-release
  * Various bug fixes
  * Small performance improvements
  * Improved support for non power of two textures
  * Updated SDL to 2.0.18
- remove 0001-Fix-format-overflow-warning-with-32-bit-gcc.patch: upstream
* Mon Dec  6 2021 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-Fix-format-overflow-warning-with-32-bit-gcc.patch
* Fri Nov 26 2021 Martin Hauke <mardnh@gmx.de>
- Fix source url
* Fri Nov 26 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.12.1
  * Bugfix release
* Thu Nov 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.12.0
  * Support for scriptable particles ported from QuakeSpasm-Spiked
    (e.g. for Arcane Dimensions). If vanilla behavior is wanted
    they can be diabled with r_fteparticles 0
* Mon Oct 25 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.11.1
  * Improved compatibility with 2021 Quake re-release
  Known issues:
  * Some entities don't animate smoothly with FTE protocol
  extensions. cl_nopext 1 is a workaround right now. Same bug
  exists in QSS.
* Sat Sep  4 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.11.0
  * Initial support for Quake 2021 re-release
  * External vis file support
- Update to version 1.10.0
  * Merged protocol extensions from QuakeSpasm-Spiked. This fixes
    non smooth movement on elevators in certain cases.
  * Custom HUD client side QuakeC support for Arcane Dimensions
    (disable with cl_nocsqc 1).
  * SIMD CPU optimizations from Andrei Drexler - especially helpful
    in complex levels like ad_tears.
  * Stencil buffer optimizations for sky rendering reducing
    overdraw.
  * Resolution scaling to 1/2 1/4 or 1/8th resolution.
  * Added support for r_fullbright & r_lightmap.
  * Implemented full r_showtris support.
  * Option in menu to set max frame rate.
  * Higher precision game time and precise frame rate throttling.
  * Fix exclusive full screen alt+tab issues.
  * Bumped default heap size to 384MB.
  Changes from beta1:
  * Fixed potential issue with Intel GPUs and render scale.
  * Renamed "filter" to "textures" in menu to make it more clear
    what the option does.
  * Fixed missing gun icons in HUD.
  Changes from beta2:
  * Fixes ambient sounds.
  * Multiple memory corruption fixes.
  * Fix compatibility with some mods.
- Update to version 1.05.3
  * Fixed dynamic lights not updating properly.
  * Added menu options for particles (GL or software style).
  * Added "exclusive" menu option to fullscreen setting to control
    VK_EXT_full_screen_exclusive.
  * Removed a bunch of rendering cvars that do nothing in vkQuake.
  * Fixed edge case with out of range fog values.
- Strip binary
* Fri May  7 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.05.2
  * Only use VK_EXT_full_screen_exclusive with NVIDIA drivers as
    people reported problems with other configurations
  * Fall back to non exclusive full screen if swap chain can't be created
  * Fix descriptor set leak
  * Fix rare crash in vertex buffer memory management
  * Fix world dynamic light update lagging one frame behind brushes
* Sat Dec 26 2020 Jacob Tice <jacob.a.tice@gmail.com>
- Update to version 1.05.1
- Drop 0001-Remove-use-of-VK_DYNAMIC_STATE_RANGE_SIZE.patch
* Sun Sep 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to fix the factory build:
  * 0001-Remove-use-of-VK_DYNAMIC_STATE_RANGE_SIZE.patch
* Fri Mar 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.04.1. Changes since 1.02.0:
  * Lots of Vulkan fixes
  * Frame rates over 72 Hz don't break physics anymore
  * Default maximum frame rate raised to 200 Hz.
  * Fix crashes with some Intel drivers and anti aliasing
  * Fix crash "out of dynamic vertex buffer space"
    in some very large custom maps
  * Fix gun position being different than in QuakeSpasm
    when status bar alpha is 0
  * Fixed alpha tested alias models
  * Fixed too large dynamic buffer allocations
  * Lightmaps are now dynamically allocated (from QuakeSpasm)
  * Particles are now rendered as quads instead of triangles
    by default (r_quadparticles) like in QuakeSpasm.
  * Fix alpha tested geo not testing depth
  * Fix issue where wrong push constants were being
    set if render size is smaller than window
  * Fixed certain UI elementes being rendered with alpha
    blending instead of alpha testing like in QS
  * Fix issue with Intel GPUs crashing when leaving full screen
  * Updated to latest QuakeSpasm code
  * Fix particle alpha being affected by fog
* Mon Jun 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.02.0
  + Frame rates over 72 Hz don't break physics anymore (from
    QuakeSpasm spiked)
  + Default maximum frame rate raised to 200 Hz.
  + Fix crashes with some Intel drivers and anti aliasing
  + Fix crash "out of dynamic vertex buffer space" in some very
    large custom maps
  + Fix gun position being different than in QuakeSpasm when status
    bar alpha is 0
  + Other minor Vulkan fixes
- Update to version 1.01.0
  + Extremely large textures should now work
  + Fixed alpha blending issue in some maps
    (e.g. xmasjam2018_bloodshot)
  + Partial support for r_showTris (world and particles)
  + Update to latest QuakeSpasm code
* Sun Oct 14 2018 sean@suspend.net
- Update to 1.00.0
  + Peformance optimizations (use function pointer instead of loader)
  + Compute shader water texture update
  + Update to latest QuakeSpasm code
* Tue Jun 27 2017 luke.nukem.jones@gmail.com
- Update to 0.96.2
  + Fix for AMD hang
- Changes from 0.96.1
  + Bump limits for Arcane Dimensions 1.60 (ad_sepulcher)
  + Fix for broken dynamic lights since version 0.92
  + Add fence between command buffer completion and present
    (required by Vulkan spec)
  + Potential optimization for some drivers: Mark command buffers as
    VK_COMMAND_BUFFER_USAGE_ONE_TIME_SUBMIT_BIT
* Thu Jun 15 2017 boris@steki.net
- update Source url to work as intended
* Tue Jun 13 2017 luke.nukem.jones@gmail.com
- Initial packaging
